@@ -22,29 +22,26 @@ TODO_OPTIONS="--timeout --summary"
 
 cd ()
 {
-	{
-		builtin cd "$@" 
-		EXIT=$?
-	} && [ -f .todo ] && devtodo ${TODO_OPTIONS}
-	( exit $EXIT )
+	builtin cd "$@"
+	RV=$?
+	[ $RV = 0 -a -r .todo ] && devtodo ${TODO_OPTIONS}
+	return $RV
 }
 
 pushd ()
 {
-	{
-		builtin pushd "$@" 
-		EXIT=$?
-	} && [ -f .todo ] && devtodo ${TODO_OPTIONS}
-	( exit $EXIT )
+	builtin pushd "$@"
+	RV=$?
+	[ $RV = 0 -a -r .todo ] && devtodo ${TODO_OPTIONS}
+	return $RV
 }
 
 popd ()
 {
-	{
-		builtin popd 
-		EXIT=$?
-	} && [ -f .todo ] && devtodo ${TODO_OPTIONS}
-	( exit $EXIT )
+	builtin popd "$@"
+	RV=$?
+	[ $RV = 0 -a -r .todo ] && devtodo ${TODO_OPTIONS}
+	return $RV
 }              
 
 # Run todo initially upon login
