@@ -749,8 +749,8 @@ int erased = 0;
 			erased++;
 			if (options.verbose > 1)
 				cout << info << "todo: permanently removing item '" << (*j) << "'" << normal << endl;
-			erase(todo, *j);
 			t->db->setDirty(true);
+			erase(todo, *j);
 		} else
 			notfound.push_back(*j);
 	}
@@ -963,7 +963,7 @@ time_t now = getCurrentDate();
 
 unsigned purged = purge(todo, now - options.purgeage * 86400);
 	if (options.verbose)
-		cout << info << "todo: purged " << purged << " items older than " << options.purgeage << " days" << endl;
+		cout << info << "todo: purged " << purged << " completed items older than " << options.purgeage << " days" << normal << endl;
 }
 
 unsigned TodoDB::purge(multiset<Todo> &todo, time_t age) {
@@ -973,13 +973,14 @@ unsigned purged = 0;
 		if (i->done && i->doneTime < age) {
 		multiset<Todo>::iterator last = i++;
 
+			cout << i->doneTime << " < " << age << endl;
+			last->db->setDirty(true);
 			todo.erase(last);
-			i->db->setDirty(true);
 			++purged;
 		} else {
-			if (i->child)
+			if (i->child) {
 				purged += purge(*i->child, age);
-			++i;
+			}
 		}
 	}
 	return purged;
